@@ -9,8 +9,6 @@
 ---
 <!--END STABILITY BANNER-->
 
-> **Status: Experimental**
-
 This library allows populating an S3 bucket with the contents of .zip files
 from other S3 buckets or from local disk.
 
@@ -108,7 +106,7 @@ when the `BucketDeployment` resource is created or updated. You can use the opti
 this behavior, in which case the files will not be deleted.
 
 ```python
-# destination_bucket is of type Bucket
+# destination_bucket: s3.Bucket
 
 s3deploy.BucketDeployment(self, "DeployMeWithoutDeletingFilesOnDestination",
     sources=[s3deploy.Source.asset(path.join(__dirname, "my-website"))],
@@ -122,7 +120,7 @@ each with its own characteristics. For example, you can set different cache-cont
 based on file extensions:
 
 ```python
-# destination_bucket is of type Bucket
+# destination_bucket: s3.Bucket
 
 s3deploy.BucketDeployment(self, "BucketDeployment",
     sources=[s3deploy.Source.asset("./website", exclude=["index.html"])],
@@ -144,7 +142,7 @@ s3deploy.BucketDeployment(self, "HTMLBucketDeployment",
 There are two points at which filters are evaluated in a deployment: asset bundling and the actual deployment. If you simply want to exclude files in the asset bundling process, you should leverage the `exclude` property of `AssetOptions` when defining your source:
 
 ```python
-# destination_bucket is of type Bucket
+# destination_bucket: s3.Bucket
 
 s3deploy.BucketDeployment(self, "HTMLBucketDeployment",
     sources=[s3deploy.Source.asset("./website", exclude=["*", "!index.html"])],
@@ -155,7 +153,7 @@ s3deploy.BucketDeployment(self, "HTMLBucketDeployment",
 If you want to specify filters to be used in the deployment process, you can use the `exclude` and `include` filters on `BucketDeployment`.  If excluded, these files will not be deployed to the destination bucket. In addition, if the file already exists in the destination bucket, it will not be deleted if you are using the `prune` option:
 
 ```python
-# destination_bucket is of type Bucket
+# destination_bucket: s3.Bucket
 
 s3deploy.BucketDeployment(self, "DeployButExcludeSpecificFiles",
     sources=[s3deploy.Source.asset(path.join(__dirname, "my-website"))],
@@ -260,8 +258,8 @@ Please note that creating VPC inline may cause stack deletion failures. It is sh
 To avoid such condition, keep your network infra (VPC) in a separate stack and pass as props.
 
 ```python
-# destination_bucket is of type Bucket
-# vpc is of type Vpc
+# destination_bucket: s3.Bucket
+# vpc: ec2.Vpc
 
 
 s3deploy.BucketDeployment(self, "DeployMeWithEfsStorage",
@@ -282,12 +280,15 @@ s3deploy.BucketDeployment(self, "DeployMeWithEfsStorage",
   which can be deployed into the bucket by this timeout.
 * When the `BucketDeployment` is removed from the stack, the contents are retained
   in the destination bucket ([#952](https://github.com/aws/aws-cdk/issues/952)).
-* Bucket deployment *only happens* during stack create/update. This means that
-  if you wish to update the contents of the destination, you will need to
-  change the source s3 key (or bucket), so that the resource will be updated.
-  This is inline with best practices. If you use local disk assets, this will
-  happen automatically whenever you modify the asset, since the S3 key is based
-  on a hash of the asset contents.
+* If you are using `s3deploy.Source.bucket()` to take the file source from
+  another bucket: the deployed files will only be updated if the key (file name)
+  of the file in the source  bucket changes. Mutating the file in place will not
+  be good enough: the custom resource will simply not run if the properties don't
+  change.
+
+  * If you use assets (`s3deploy.Source.asset()`) you don't need to worry
+    about this: the asset system will make sure that if the files have changed,
+    the file name is unique and the deployment will run.
 
 ## Development
 
@@ -959,7 +960,7 @@ class CacheControl(
 
     Example::
 
-        # destination_bucket is of type Bucket
+        # destination_bucket: s3.Bucket
         
         s3deploy.BucketDeployment(self, "BucketDeployment",
             sources=[s3deploy.Source.asset("./website", exclude=["index.html"])],
@@ -1066,7 +1067,7 @@ class DeploymentSourceContext:
             import aws_cdk.aws_iam as iam
             import aws_cdk.aws_s3_deployment as s3_deployment
             
-            # role is of type Role
+            # role: iam.Role
             
             deployment_source_context = s3_deployment.DeploymentSourceContext(
                 handler_role=role
@@ -1367,7 +1368,7 @@ class SourceConfig:
             import aws_cdk.aws_s3 as s3
             import aws_cdk.aws_s3_deployment as s3_deployment
             
-            # bucket is of type Bucket
+            # bucket: s3.Bucket
             
             source_config = s3_deployment.SourceConfig(
                 bucket=bucket,
